@@ -1,24 +1,18 @@
 # Django settings for django_hello project used on Debian systems.
 
 from django_debian.settings import Settings
+
+from lava_server.extension import loader
 from lava_server.settings.production import *
 
 # Load application settings from django-debian integration package
-debian_settings = Settings("lava")
+debian_settings = Settings("lava-server")
 
 # Load default database from Debian integration
 DATABASES = {
     'default': debian_settings.default_database
 }
 
-# Enable constrained dataview database if requested
-if debian_settings._settings.get("use_dataview_database"):
-    # Copy everything from the default database and append _dataview to user
-    # name. The rest is out of scope (making sure it's actually setup
-    # properly, having permissions to login, permissions to view proper data)
-    DATABASES['dataview'] = dict(DATABASES['default'])
-    DATABASES['dataview']['USER'] += "_dataview"
-
 # Load secret key from Debian integration
 SECRET_KEY = debian_settings.SECRET_KEY
 
@@ -47,10 +41,8 @@ ADMIN_MEDIA_PREFIX = debian_settings.ADMIN_MEDIA_PREFIX
 # List of absolute pathnames used to resolve templates.
 TEMPLATE_DIRS = debian_settings.TEMPLATE_DIRS
 
-# TODO: Debianize this
-STATICFILES_DIRS = [
-    ('', "/usr/share/lava/htdocs"),
-]
+# Like TEMPLATE_DIRS but for static files
+STATICFILES_DIRS = debian_settings.STATICFILES_DIRS
 
 # A tuple that lists people who get code error notifications. When DEBUG=False
 # and a view raises an exception, Django will e-mail these people with the
@@ -68,3 +60,6 @@ MANAGERS = debian_settings.MANAGERS
 # See also IGNORABLE_404_STARTS, IGNORABLE_404_ENDS and Error reporting via
 # e-mail.
 SEND_BROKEN_LINK_EMAILS=debian_settings.SEND_BROKEN_LINK_EMAILS
+
+# Load extensions
+loader.contribute_to_settings(locals(), debian_settings)
